================
Materials & EMA
================

.. automodule:: elli.materials

Abstract base classes
---------------------
.. autoclass:: elli.materials.Material
    :members:

.. autoclass:: elli.materials.MixtureMaterial
    :members:

.. autoclass:: elli.materials.SingleMaterial
    :members:

Isotropic and non-isotropic materials
-------------------------------------
.. autoclass:: elli.materials.IsotropicMaterial
    :members:

.. autoclass:: elli.materials.UniaxialMaterial
    :members:

.. autoclass:: elli.materials.BiaxialMaterial
    :members:

Effective medium approximations
-------------------------------
.. autoclass:: elli.materials.VCAMaterial
    :members:

.. autoclass:: elli.materials.BruggemanEMA
    :members:

.. autoclass:: elli.materials.MaxwellGarnettEMA
    :members:

.. autoclass:: elli.materials.LooyengaEMA
    :members:
